// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:supabase_flutter/supabase_flutter.dart';
import 'package:wyatt_authentication/wyatt_authentication.dart';
import 'package:wyatt_authentication_example/account_model.dart';
import 'package:wyatt_authentication_example/app.dart';
import 'package:wyatt_authentication_supabase/wyatt_authentication_supabase.dart';

const supabaseUrl = 'https://yarkjotsulnccxdkztiv.supabase.co';
const supabaseKey = String.fromEnvironment('SUPABASE_KEY');

Future<void> main(List<String> args) async {
  WidgetsFlutterBinding.ensureInitialized();

  await Supabase.initialize(
    url: supabaseUrl,
    anonKey: supabaseKey,
  );

  Auth.initialize(
    platform: AuthenticationSupabasePlatform(
      accountMapper: (user) {
        if (user == null) {
          return null;
        }
        return AccountModel(
          email: user.email ?? 'email',
        );
      },
    ),
  );

  runApp(const App());
}
